@@ -5,12 +5,14 @@ from .func import *
 from .events import *
 from .iterable import *
 from .runners import *
+from .sleep import *
 
 
 __all__ = cls.__all__ + func.__all__ + events.__all__ + iterable.__all__ + runners.__all__
 
+
 __title__ = 'asyncify'
 __author__ = 'The Master'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2022-present The Master'
-__version__ = '1.2.post0'
+__version__ = '1.3'
