@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import asyncio
 import functools
 import sys
@@ -62,12 +64,12 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
     .. versionadded:: 1.1
     """
 
-    def event(self, func: "Callable[P, T]") -> "Callable[P, T]":
+    def event(self, func: Callable[P, T]) -> Callable[P, T]:
         """|deco|
 
         Register a function to be called when an event loop policy method is called.
         The name of the functions should match the event loop policy method.
-        the valid names are ``get_event_loop``, ``set_event_loop``, ``new_event_loop``,
+        The valid names are ``get_event_loop``, ``set_event_loop``, ``new_event_loop``,
         ``get_child_watcher``, ``set_child_watcher``
 
         Example
@@ -83,22 +85,24 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
 
         Raises
         -------
+        TypeError
+            `func` is not a callable.
         RuntimeError
             The name either is invalid or is not supported on Windows.
         """
         if not isinstance(func, Callable):
-            raise TypeError('Expected a callable, not {!r}'.format(func))
+            raise TypeError(f'Expected a callable, got {func.__class__.__name__!r}')
 
         if sys.platform == 'win32' and func.__name__ in _UNIX_ONLY_NAMES:
-            raise RuntimeError('{!r} is not supported on windows.'.format(func.__name__))
+            raise RuntimeError(f'{func.__name__!r} is not supported on windows.')
 
         if func.__name__ not in _VALID_NAMES:
-            raise RuntimeError('{!r} is not a valid function name. {!r} are valid.'.format(func.__name__, _VALID_NAMES))
+            raise RuntimeError(f'{func.__name__!r} is not a valid function name. {_VALID_NAMES} are valid.')
 
         old: Callable[..., Any] = getattr(super(), func.__name__)
 
         @functools.wraps(old)
-        def updated(*args: "P.args", **kwargs: "P.kwargs") -> Any:
+        def updated(*args: P.args, **kwargs: P.kwargs) -> Any:
             func(*args, **kwargs)
             return old(*args, **kwargs)
 
@@ -148,6 +152,6 @@ class EventsEventLoopPolicy(asyncio.DefaultEventLoopPolicy):
             `policy_cls` does not inherit from `asyncio.AbstractEventLoopPolicy`.
         """
         if asyncio.AbstractEventLoop not in policy_cls.__bases__:
-            raise TypeError('policy_cls must inherited from asyncio.AbstractEventLoopPolicy')
+            raise TypeError('policy_cls must inherited from asyncio.AbstractEventLoopPolicy.')
 
         cls.__bases__: Tuple[Type[Any], ...] = (policy_cls,) + cls.__bases__[1:]
